# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .failure_type import FailureType
from .parent_biomarker_data import ParentBiomarkerData


class MissingBiomarkerResult(UniversalBaseModel):
    name: str
    slug: str
    inferred_failure_type: FailureType
    note: typing.Optional[str] = None
    loinc: typing.Optional[str] = None
    loinc_slug: typing.Optional[str] = None
    provider_id: typing.Optional[str] = None
    source_markers: typing.Optional[typing.List[ParentBiomarkerData]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
